## 使い方
cszpはコマンドラインと同じ対話式のシステムを導入している。以下の画像の通り、選択等をしていくだけでプログラムを実行することができる。
![photo](https://cdn-ak.f.st-hatena.com/images/fotolife/k/kumitatepazuru/20200621/20200621185025.png)

## menu画面のコマンドの説明

### startコマンド
rcssserverの実行をする。事前に必要な引数はこのあとも説明する質問により自動入力される。

### testコマンド
startコマンドと似ているが、これはプログラムが実行可能か、または実行できるかを確認できるように作られている。試合時間が200tickに設定されている。こちらも後ほど説明する。

### settingコマンド
cszpの設定をする。詳しくは後ほど説明する。

### resetコマンド
設定ファイルが破損したりして起動できなくなった場合、このコマンドを使い設定を初期化します。復元はできません。

### loopコマンド
rcssserverを指定した回数実行し、結果を設定した場合、csvファイルに保存してくれるスグレモノ。synchモードの実行も設定すれば可能。後ほど、説明する。

### langコマンド
言語を変更する。いま対応している言語は、日本語と英語。 

### serverコマンド
過去に試合したデータを確認することができる。後ほど説明する。

### pluginコマンド
プラグイン情報を表示・インストールをすることができる。こちらも後ほど説明する。

### aboutコマンド
cszp・PCの情報・インストールが確認できる。後ほど解説する。

### helpコマンド
cszpの使い方等が確認できる。

### exitコマンド
プログラムを終了する。Ctrl+Cで終了することも可能（実行中にやると不具合が発生する可能性あり）
 
## 起動できない

 * もし、下の画像に似たような警告が出てプログラムが止まる場合はEnterキーを押すと実行できる。原因としてはpluginsフォルダの中に余計なものまたは実行できないプラグインが存在する場合に表示される。
![photo](https://cdn-ak.f.st-hatena.com/images/fotolife/k/kumitatepazuru/20200621/20200621185709.png)